//
//  Controller.m
//  PDFSplit
//
//  Created by Debenu Pty Ltd on 9/20/12.
//  Copyright (c) 2012 Debenu Pty Ltd. All rights reserved.
//

#import "Controller.h"
#import "DebenuPDFLibraryDylibClass1015.h"

@implementation Controller

- (BOOL)splitFile:(NSString*)filePath to:(NSString*)toDirPath error:(NSError**)error
{
    // extract text from pdf
    NSBundle* mainBundle = [NSBundle mainBundle];
    NSString* dylibPath = [mainBundle privateFrameworksPath];
    
    dylibPath = [dylibPath stringByAppendingPathComponent:@"libDebenuPDFLibraryDylib1015.dylib"];
    
    DebenuPDFLibraryDylibClass1015* DQPL = [[[DebenuPDFLibraryDylibClass1015 alloc] initWithDylibFileName:dylibPath] autorelease];
    
    NSString* key = @"*** insert your license key here ***";
    
    if( [DQPL UnlockKey:key] != 1 ) {
        
        if( error != NULL ) {
            *error = [NSError errorWithDomain:@"DQPLErrorDomain"
                                         code:0
                                     userInfo:[NSDictionary dictionaryWithObject:[NSString stringWithFormat:@"Failed to unlock DQPL with %@", key] forKey:NSLocalizedDescriptionKey]];

        }
        
        return NO;
    }
    
    if( [DQPL LoadFromFile:filePath :@""] != 1 ) {// fail to load file.

        if( error != NULL ) {

            NSString* description = [NSString stringWithFormat:@"Failed to load %@", filePath];

            *error = [NSError errorWithDomain:@"DQPLErrorDomain"
                                         code:0
                                     userInfo:[NSDictionary dictionaryWithObject:description forKey:NSLocalizedDescriptionKey]];
            
        }
        
        return NO;
    }
    

    // Use the SelectedDocument function to get the
    // document ID of the file that we just loaded.
    
    int documentID = [DQPL SelectedDocument];
    
    // Count the total number of pages in the
    // selected document. We need the total
    // number of pages before we can use the
    // ExtractFilePages function.
    
    int pageCount = [DQPL PageCount];
    
    // Remove the selected document from memory.
    if( [DQPL RemoveDocument:documentID] != 1 ) {// fail to remove selected document from memory
        
        if( error != NULL ) {
            *error = [NSError errorWithDomain:@"DQPLErrorDomain"
                                         code:0
                                     userInfo:[NSDictionary dictionaryWithObject:@"DQPL Error" forKey:NSLocalizedDescriptionKey]];
            
        }
        
        return NO;
    }
    
    // Loop through each page in the document
    // and use the ExtractFilePages function
    // to copy and save each page in the
    // document to a new document.
    
    NSString* sourceFileName = [filePath lastPathComponent];
    for( int i = 1; i <= pageCount; ++i ) {
        
        NSString* toFileName = [NSString stringWithFormat:@"%@_%d.pdf", sourceFileName, i];
        NSString* toFileFullPath = [toDirPath stringByAppendingPathComponent:toFileName];
        NSString* rangeString = [NSString stringWithFormat:@"%d", i];
        
        if( [DQPL ExtractFilePages:filePath :@"" :toFileFullPath :rangeString] != 1 ) {// error
            
            if( error != NULL ) {
                
                NSString* description = [NSString stringWithFormat:@"Error occured while extracting %d's page", i];
                
                *error = [NSError errorWithDomain:@"DQPLErrorDomain"
                                             code:0
                                         userInfo:[NSDictionary dictionaryWithObject:description forKey:NSLocalizedDescriptionKey]];
                
            }
            
            return NO;
        }
    }
    
    return YES;
}

@end
